parse_var

Function parse_var 

pub fn parse_var(src: &str, name: &str) -> Result<Parsed, String>
Parse the array assigned to $name (for Nextcloud, CONFIG). A file that is a script rather than a config array - one that sets other variables first - is read from the right assignment instead of the first =.