resolve_pair

Function resolve_pair 

pub fn resolve_pair(
    conn: &Connection,
    project: Option<&str>,
    exporter: Option<&str>,
    from: Option<i64>,
    to: Option<i64>,
) -> Result<(i64, i64), String>
Picks the two snapshots a diff should compare. With from/to unset, the two newest of the stream named by project (and exporter, which is required when the project has more than one stream, such as Compose and its .env).