thumbprint

Function thumbprint 

pub fn thumbprint(jwk: &Value) -> Result<String, String>
The RFC 7638 thumbprint of a public JWK, which is the kid a verifier would derive and the one used when the entry names none.