pub struct EntryExposure {
pub entry_id: String,
pub provider: String,
pub key_id: String,
pub fields: Vec<String>,
pub first_seen: String,
pub last_seen: String,
pub times: usize,
pub still_current: bool,
pub removed: bool,
pub short: bool,
pub console_url: Option<String>,
pub via: Vec<String>,
}Fields
entry_id: Stringprovider: Stringkey_id: Stringfields: Vec<String>first_seen: Stringlast_seen: Stringtimes: usizestill_current: boolThe value that was on the host is still the entry’s value, so it still opens whatever it opened: rotate it.
removed: boolThe entry no longer exists in the vault.
short: boolconsole_url: Option<String>via: Vec<String>Trait Implementations
Sourceimpl Clone for EntryExposure
impl Clone for EntryExposure
Sourcefn clone(&self) -> EntryExposure
fn clone(&self) -> EntryExposure
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EntryExposure
impl Debug for EntryExposure
Sourceimpl PartialEq for EntryExposure
impl PartialEq for EntryExposure
Sourceimpl Serialize for EntryExposure
impl Serialize for EntryExposure
impl StructuralPartialEq for EntryExposure