pub fn verify(conn: &Connection) -> Result<bool, String>Expand description
Integrity: every row hashes to its rev, and the rows hash to the stored token.
pub fn verify(conn: &Connection) -> Result<bool, String>Integrity: every row hashes to its rev, and the rows hash to the stored token.